NDArrayBoolean

Trait NDArrayBoolean 

pub trait NDArrayBoolean<O>: NDArray + Sized
where O: NDArray<DType = Self::DType>,
{ type Output: Access<u8>; // Required methods fn and( self, other: O, ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>; fn or( self, other: O, ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>; fn xor( self, other: O, ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>; }
Boolean array operations

Required Associated Types

Required Methods

fn and(self, other: O) -> Result<Array<u8, Self::Output, Self::Platform>, Error>

Construct a boolean and comparison with the other array.

fn or(self, other: O) -> Result<Array<u8, Self::Output, Self::Platform>, Error>

Construct a boolean or comparison with the other array.

fn xor(self, other: O) -> Result<Array<u8, Self::Output, Self::Platform>, Error>

Construct a boolean xor comparison with the other array.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors