NDArrayBooleanScalar

Trait NDArrayBooleanScalar 

pub trait NDArrayBooleanScalar: NDArray + Sized {
    type Output: Access<u8>;

    // Required methods
    fn and_scalar(
        self,
        other: Self::DType,
    ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>;
    fn or_scalar(
        self,
        other: Self::DType,
    ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>;
    fn xor_scalar(
        self,
        other: Self::DType,
    ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>;
}
Boolean array operations with a scalar argument

Required Associated Types

Required Methods

fn and_scalar( self, other: Self::DType, ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>

Construct a boolean and operation with the other value.

fn or_scalar( self, other: Self::DType, ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>

Construct a boolean or operation with the other value.

fn xor_scalar( self, other: Self::DType, ) -> Result<Array<u8, Self::Output, Self::Platform>, Error>

Construct a boolean xor operation with the other value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors