pub trait NDArrayReduceAll: NDArrayRead {
// Required methods
fn max_all(self) -> Result<Self::DType, Error>
where Self::DType: Real;
fn min_all(self) -> Result<Self::DType, Error>
where Self::DType: Real;
fn product_all(self) -> Result<Self::DType, Error>;
fn sum_all(self) -> Result<Self::DType, Error>;
}Expand description
Array reduce operations
Required Methods
Sourcefn max_all(self) -> Result<Self::DType, Error>
fn max_all(self) -> Result<Self::DType, Error>
Return the maximum of all elements in this array.
Sourcefn min_all(self) -> Result<Self::DType, Error>
fn min_all(self) -> Result<Self::DType, Error>
Return the minimum of all elements in this array.
Sourcefn product_all(self) -> Result<Self::DType, Error>
fn product_all(self) -> Result<Self::DType, Error>
Return the product of all elements in this array.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".