NDArrayReduceAll

Trait NDArrayReduceAll 

pub trait NDArrayReduceAll: NDArrayRead {
    // Required methods
    fn max_all(self) -> Result<Self::DType, Error>
       where Self::DType: Real;
    fn min_all(self) -> Result<Self::DType, Error>
       where Self::DType: Real;
    fn product_all(self) -> Result<Self::DType, Error>;
    fn sum_all(self) -> Result<Self::DType, Error>;
}
Array reduce operations

Required Methods

fn max_all(self) -> Result<Self::DType, Error>
where Self::DType: Real,

Return the maximum of all elements in this array.

fn min_all(self) -> Result<Self::DType, Error>
where Self::DType: Real,

Return the minimum of all elements in this array.

fn product_all(self) -> Result<Self::DType, Error>

Return the product of all elements in this array.

fn sum_all(self) -> Result<Self::DType, Error>

Return the sum of all elements in this array.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors